<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a Plural Form for "Maltese" language.
 */
#[StringPluralForm(
  id: "five_forms_maltese",
  admin_label: new TranslatableMarkup("Five Forms Maltese"),
  description: new TranslatableMarkup("Case in the Maltese language."),
)]
class FiveFormsMaltese extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 5;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "(n == 1) ? 0 : ((n == 2) ? 1 : ((n == 0 || n % 100 >= 3 && n % 100 <= 10) ? 2 : ((n % 100 >= 11 && n % 100 <= 19) ? 3 : 4)))";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "mt",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return ($n == 1) ? 0 : (($n == 2) ? 1 : (($n == 0 || $n % 100 >= 3 && $n % 100 <= 10) ? 2 : (($n % 100 >= 11 && $n % 100 <= 19) ? 3 : 4)));
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("one"),
      1 => new TranslatableMarkup("two"),
      2 => new TranslatableMarkup("0, 3~10, 103~109, ..."),
      3 => new TranslatableMarkup("11~19, 111~117, ..."),
      4 => new TranslatableMarkup("others"),
    };
  }

}
