<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a Plural Form for "Manx" language.
 */
#[StringPluralForm(
  id: "four_forms_manx",
  admin_label: new TranslatableMarkup("Four Forms Manx"),
  description: new TranslatableMarkup("Case in the Manx language."),
)]
class FourFormsManx extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 4;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "(n % 10 == 1) ? 0 : ((n % 10 == 2) ? 1 : ((n % 100 == 0 || n % 100 == 20 || n % 100 == 40 || n % 100 == 60 || n % 100 == 80) ? 2 : 3))";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "gv",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return ($n % 10 == 1) ? 0 : (($n % 10 == 2) ? 1 : (($n % 100 == 0 || $n % 100 == 20 || $n % 100 == 40 || $n % 100 == 60 || $n % 100 == 80) ? 2 : 3));
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("1, 11, 21, 31, ..."),
      1 => new TranslatableMarkup("2, 12, 22, 32, ..."),
      2 => new TranslatableMarkup("0, 20, 40, 50, ..."),
      3 => new TranslatableMarkup("3, 4, 5, 6, ..."),
    };
  }

}
