<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a custom block plugin.
 */
#[StringPluralForm(
  id: "only_one_form",
  admin_label: new TranslatableMarkup("Only one form"),
  description: new TranslatableMarkup("Some languages only require one single form. There is no distinction between the singular and plural form."),
)]
class OnlyOneForm extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 1;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "0";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "ja",
      "vi",
      "ko",
      "th",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return 0;
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("All cases"),
    };
  }

}
