<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a custom block plugin.
 */
#[StringPluralForm(
  id: "six_forms_arabic",
  admin_label: new TranslatableMarkup("Six forms, special cases for one, two, all numbers ending in 02, 03, … 10, all numbers ending in 11 … 99, and others"),
  description: new TranslatableMarkup("Case in some Afroasiatic family language like Arabic."),
)]
class SixFormsArabic extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 6;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 ? 4 : 5";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "ar",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    $index = match ($n) {
      0 => 0,
      1 => 1,
      2 => 2,
      default =>  ($n % 100 >= 3 && $n % 100 <= 10) ? 3 : ($n % 100 >= 11 ? 4 : 5)
    };
    return $index;
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("zero"),
      1 => new TranslatableMarkup("one"),
      2 => new TranslatableMarkup("two"),
      3 => new TranslatableMarkup("all numbers ending in 02, 03, … 10"),
      4 => new TranslatableMarkup("all numbers ending in 11 … 99"),
      5 => new TranslatableMarkup("other cases"),
    };
  }

}
