<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a Plural Form for "Cornish" language.
 */
#[StringPluralForm(
  id: "six_forms_cornish",
  admin_label: new TranslatableMarkup("Six Forms Cornish"),
  description: new TranslatableMarkup("Case in the Cornish language."),
)]
class SixFormsCornish extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 6;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "(n == 0) ? 0 : ((n == 1) ? 1 : (((n % 100 == 2 || n % 100 == 22 || n % 100 == 42 || n % 100 == 62 || n % 100 == 82) || n % 1000 == 0 && (n % 100000 >= 1000 && n % 100000 <= 20000 || n % 100000 == 40000 || n % 100000 == 60000 || n % 100000 == 80000) || n != 0 && n % 1000000 == 100000) ? 2 : ((n % 100 == 3 || n % 100 == 23 || n % 100 == 43 || n % 100 == 63 || n % 100 == 83) ? 3 : ((n != 1 && (n % 100 == 1 || n % 100 == 21 || n % 100 == 41 || n % 100 == 61 || n % 100 == 81)) ? 4 : 5))))";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "kw",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return ($n == 0) ? 0 : (($n == 1) ? 1 : ((($n % 100 == 2 || $n % 100 == 22 || $n % 100 == 42 || $n % 100 == 62 || $n % 100 == 82) || $n % 1000 == 0 && ($n % 100000 >= 1000 && $n % 100000 <= 20000 || $n % 100000 == 40000 || $n % 100000 == 60000 || $n % 100000 == 80000) || $n != 0 && $n % 1000000 == 100000) ? 2 : (($n % 100 == 3 || $n % 100 == 23 || $n % 100 == 43 || $n % 100 == 63 || $n % 100 == 83) ? 3 : (($n != 1 && ($n % 100 == 1 || $n % 100 == 21 || $n % 100 == 41 || $n % 100 == 61 || $n % 100 == 81)) ? 4 : 5))));
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("0"),
      1 => new TranslatableMarkup("1"),
      2 => new TranslatableMarkup("2, 22, 42, 62, ..."),
      3 => new TranslatableMarkup("3, 23, 43, 63, 83, ..."),
      4 => new TranslatableMarkup("21, 41, 61, ..."),
      5 => new TranslatableMarkup("others"),
    };
  }

}
