<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a Plural Form for "Spanish, Italia, Portuguese, ..." languages.
 */
#[StringPluralForm(
  id: "three_forms_special_case_for_1000000",
  admin_label: new TranslatableMarkup("Three Forms Special Case For 1000000"),
  description: new TranslatableMarkup("Case in the Spanish, Italian, Portuguese, etc."),
)]
class ThreeFormsSpecialCaseFor1000000 extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 3;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "(n == 1) ? 0 : ((n != 0 && n % 1000000 == 0) ? 1 : 2)";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "ca",
      "es",
      "it",
      "pt_PT",
      "vec",
      "pt",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return ($n == 1) ? 0 : (($n != 0 && $n % 1000000 == 0) ? 1 : 2);
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("one"),
      1 => new TranslatableMarkup("1000000, 2000000, ..."),
      2 => new TranslatableMarkup("0, 2~16, 100, 1000, 10000, ..."),
    };
  }

}
