<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a Plural Form for "French and Portuguese" languages.
 */
#[StringPluralForm(
  id: "three_forms_special_case_for_1000000_french",
  admin_label: new TranslatableMarkup("Three Forms Special Case For 1000000 (fr, pt)"),
  description: new TranslatableMarkup("Case in the French, Portuguese, etc."),
)]
class ThreeFormsSpecialCaseFor1000000French extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 3;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "(n == 0 || n == 1) ? 0 : ((n != 0 && n % 1000000 == 0) ? 1 : 2)";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "fr",
      "pt",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return ($n == 0 || $n == 1) ? 0 : (($n % 1000000 == 0) ? 1 : 2);
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("0, 1"),
      1 => new TranslatableMarkup("1000000, 2000000, ..."),
      2 => new TranslatableMarkup("2~17, 100, 1000, 10000, ..."),
    };
  }

}
