<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a custom block plugin.
 */
#[StringPluralForm(
  id: "two_forms_singular_for_one_only",
  admin_label: new TranslatableMarkup("Two forms, singular used for one only"),
  description: new TranslatableMarkup("This is the form used in most existing programs since it is what English is using."),
)]
class TwoFormsSingularForOneOnly extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 2;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "n != 1";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "en",
      "de",
      "nl",
      "sv",
      "da",
      "no",
      "nb",
      "nn",
      "fo",
      "es",
      "pt",
      "it",
      "el",
      "bg",
      "fi",
      "et",
      "hu",
      "he",
      "id",
      "eo",
      "tr",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return ($n != 1);
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("one"),
      1 => new TranslatableMarkup("other"),
    };
  }

}
