<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a custom block plugin.
 */
#[StringPluralForm(
  id: "two_forms_singular_for_zero_and_one",
  admin_label: new TranslatableMarkup("Two forms, singular used for zero and one"),
  description: new TranslatableMarkup("Exceptional case in the language family like Brazilian Portuguese and French."),
)]
class TwoFormsSingularForZeroAndOne extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 2;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "n>1";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "pt",
      "fr",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return ($n > 1);
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("zero, one"),
      1 => new TranslatableMarkup("other"),
    };
  }

}
