<?php

namespace Drupal\string_plural_form\Plugin\StringPluralForm;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\string_plural_form\Attribute\StringPluralForm;
use Drupal\string_plural_form\StringPluralFormBase;

/**
 * Provides a Plural Form for "Tamazight" language.
 */
#[StringPluralForm(
  id: "two_forms_tamazight",
  admin_label: new TranslatableMarkup("Five Forms Tamazight"),
  description: new TranslatableMarkup("Case in the Tamazight language."),
)]
class TwoFormsTamazight extends StringPluralFormBase {

  /**
   * {@inheritdoc}
   */
  public function getGettextNplurals(): int {
    return 2;
  }

  /**
   * {@inheritdoc}
   */
  public function getGettextPlural(): string {
    return "n >= 2 && (n < 11 || n > 99)";
  }

  /**
   * {@inheritdoc}
   */
  public function getAssociatedLanguageCodes(): array {
    return [
      "tzm",
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIndex(int $n): int {
    return $n >= 2 && ($n < 11 || $n > 99);
  }

  /**
   * {@inheritdoc}
   */
  public function getIndexLabel(int $index): TranslatableMarkup {
    return match($index) {
      0 => new TranslatableMarkup("0, 1, 11~99"),
      1 => new TranslatableMarkup("others"),
    };
  }

}
